==> haskell-x509-store-1.6.2-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-GG9hffQSq5N919YaMDAdmw
key: x509-store-1.6.2-GG9hffQSq5N919YaMDAdmw
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: 796c16becbe890bd70993358099ff496
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-GG9hffQSq5N919YaMDAdmw
depends:
    asn1-encoding-0.9.4-Az92imiHLOLFcqxR2hoR73
    asn1-types-0.3.2-666D9GcolNS7cz58NvfKzt base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.21-HmFMsJMITqYC3JT3NLI1v7 directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-Is1xMNrGox82NbIQkXrXMb
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.2-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-8q4nvQla4ys9H4WxljQWnR
key: x509-store-1.6.2-8q4nvQla4ys9H4WxljQWnR
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: b148a6be0173b9428ccefbc8dc8623e7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-8q4nvQla4ys9H4WxljQWnR
depends:
    asn1-encoding-0.9.4-Az92imiHLOLFcqxR2hoR73
    asn1-types-0.3.2-666D9GcolNS7cz58NvfKzt base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-Yx9o4pWhKT9oEOq4Ruav1 directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-J5sTDIuLtafDFxhcFajtWr
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
